==> migrate_wizard-2.0.7-alpha1.tar.gz: migrate_wizard/src/Entity/OriginParagraphItem.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the Migration Group entity.
 *
 * The migration group entity is used to group active migrations, as well as to
 * store shared migration configuration.
 *
 * @ConfigEntityType(
 *   id = "origin_paragraph_item",
 *   label = @Translation("Origin Paragraph Item"),
 *   handlers = {
 *     "list_builder" = "Drupal\migrate_wizard\Controller\OriginParagraphItemListBuilder",
 *   },
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label"
 *   },
 *   config_export = {
 *     "id",
 *     "id_origin",
 *     "database",
 *     "use_env",
 *     "key",
 *     "target",
 *     "label",
 *     "source_type",
 *     "module",
 *     "shared_configuration",
 *   }
 * )
 */
class OriginParagraphItem extends ConfigEntityBase implements OriginParagraphItemInterface {


}

==> migrate_wizard-2.0.10-alpha1.tar.gz: migrate_wizard/src/Entity/OriginParagraphItem.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the Migration Group entity.
 *
 * The migration group entity is used to group active migrations, as well as to
 * store shared migration configuration.
 *
 * @ConfigEntityType(
 *     id="origin_paragraph_item",
 *     label=@Translation("Origin Paragraph Item"),
 *     handlers={
 *         "list_builder": "Drupal\migrate_wizard\Controller\OriginParagraphItemListBuilder",
 *     },
 *     entity_keys={
 *         "id": "id",
 *         "label": "label"
 *     },
 *     config_export={
 *         "id",
 *         "id_origin",
 *         "database",
 *         "use_env",
 *         "key",
 *         "target",
 *         "label",
 *         "source_type",
 *         "module",
 *         "shared_configuration",
 *     }
 * )
 */
class OriginParagraphItem extends ConfigEntityBase implements OriginParagraphItemInterface {

}
